"""Zaza functional tests."""
import unittest

import requests

from zaza import model


class BaseThrukMasterTest(unittest.TestCase):
    """Base for thruk-master charm tests."""

    _admin_pass = None

    @classmethod
    def setUpClass(cls):
        """Set up test env."""
        cls.model_name = model.get_juju_model()
        cls.application_name = "thruk-master"
        cls.thruk_master_unit = "thruk-master/0"
        cls.thruk_master_ip = model.get_app_ips(cls.application_name)[0]

    def cat_unit(self, unit, path):
        """Run cat on a unit.

        Assumption: the file will not be empty.
        Empty stdout will be treated as an error.
        """
        unit_res = model.run_on_unit(unit, "sudo cat {}".format(path))
        stdout = unit_res.get("Stdout", "")
        if len(stdout) == 0:
            stderr = unit_res.get("Stderr", "")
            msg = "Could not cat file {}.  Stderr: {}".format(path, stderr)
            raise RuntimeError(msg)
        return stdout

    @property
    def thrukadmin_password(self):
        """Get thrukadmin password."""
        if self._admin_pass is None:
            self._admin_pass = self.cat_unit(
                self.thruk_master_unit, "/var/lib/thruk/thrukadmin.passwd"
            ).strip()
        return self._admin_pass


class CharmOperationTest(BaseThrukMasterTest):
    """Verify operations."""

    def test_01_http_check(self):
        """Verify http thruk interface is reachable."""
        host_url = "http://{}/thruk/".format(self.thruk_master_ip)
        req = requests.get(host_url, auth=("thrukadmin", self.thrukadmin_password))
        self.assertTrue(req.status_code == 200)
